@@ -3,38 +3,44 @@
 #' This function is a wrapper of the \code{\link[Ckmeans.1d.dp]{ahist}} function
 #' for plotting nicely the distribution of the MCC models' values.
 #'
-#' @param models.mcc.no.nan.sorted a numeric sorted vector of Matthews
-#' Correlation Coefficient (MCC) scores, one for each model (no NaNs included).
-#' The \emph{names} attribute holds the models' names.
+#' @param models.mcc a numeric vector of Matthews
+#' Correlation Coefficient (MCC) scores, one for each model.
+#' The \emph{names} attribute may hold the models' names (but it is not required).
 #' @param models.cluster.ids a numeric vector of cluster ids assigned to each
-#' model. It is the result of using \code{\link[Ckmeans.1d.dp]{Ckmeans.1d.dp}}
-#' with input the sorted vector of the models' MCC values with no NaNs included
-#' (\code{models.mcc.no.nan.sorted}).
+#' model. It can be the result of using \code{\link[Ckmeans.1d.dp]{Ckmeans.1d.dp}}
+#' with input the models' MCC values (\code{models.mcc}) and the number of clusters
+#' (\code{num.of.mcc.classes}).
 #' @param num.of.mcc.classes numeric. A positive integer (>2) that signifies the
-#' number of mcc classes (groups) that we should split the models MCC values
-#' (excluding the 'NaN' values).
-#' @param mcc.class.ids a numeric vector ranging from from 1 to
-#' \code{num.of.mcc.classes}.
+#' number of mcc classes (groups) that we should split the models MCC values.
+#'
+#' @examples
+#' models.mcc = c(-0.04, -0.17, 0.15, -0.24, -0.02 , 0.27, -0.42 , 0.38)
+#' models.cluster.ids = c(2,2,3,1,2,3,1,3)
+#' num.of.mcc.classes = 3
+#' plot_mcc_classes_hist(models.mcc, models.cluster.ids, num.of.mcc.classes)
 #'
 #' @importFrom grDevices rainbow
 #' @importFrom graphics legend
 #' @importFrom Ckmeans.1d.dp ahist
 #' @export
-plot_mcc_classes_hist = function(models.mcc.no.nan.sorted, models.cluster.ids,
-                                 num.of.mcc.classes, mcc.class.ids) {
-  min.x.value = round(min(models.mcc.no.nan.sorted) - 0.1, digits = 1)
-  max.x.value = round(max(models.mcc.no.nan.sorted) + 0.1, digits = 1)
+plot_mcc_classes_hist = function(models.mcc, models.cluster.ids, num.of.mcc.classes) {
+  stopifnot(num.of.mcc.classes >= 2)
+  mcc.class.ids = 1:num.of.mcc.classes
+  min.x.value = round(min(models.mcc) - 0.1, digits = 1)
+  max.x.value = round(max(models.mcc) + 0.1, digits = 1)
   rainbow.colors = rainbow(num.of.mcc.classes)
 
-  ahist(models.mcc.no.nan.sorted, k = num.of.mcc.classes,
+  ahist(models.mcc, k = num.of.mcc.classes,
         main = "Model MCC-Classification", xlab = "MCC value",
-        sub = paste("n =", length(models.mcc.no.nan.sorted), "models, k =",
+        sub = paste("n =", length(models.mcc), "models, k =",
                     num.of.mcc.classes, "classes"),
         col = rainbow.colors, col.stick = rainbow.colors[models.cluster.ids],
         xlim = c(min.x.value, max.x.value))
 
   legend("topright", legend = mcc.class.ids, title = "MCC Classes",
          col = rainbow.colors, lty = 1, lwd = 10)
+
+  TRUE
 }
 
 #' Bar plot of model stats
@@ -55,12 +61,21 @@ plot_mcc_classes_hist = function(models.mcc.no.nan.sorted, models.cluster.ids,
 #' to 3 digits after the decimal point. Default value: FALSE.
 #' @param threshold integer. Values from the \code{model.stats} that are \emph{less
 #' or equal} to the threshold will be pruned. Use it when there too many
-#' categories and the graph appears too dense. Default value: 0
+#' categories and the figure appears too dense. Default value: 0
+#' @param ylim.add integer. Signifies the height to add to the upper
+#' \code{ylim} parameter on the barplot, in addition to the maximum bar height
+#' across the whole plot. Default value is 0.
+#'
+#' @examples
+#' x = c(rep(1,100), rep(2,423), rep(3,231), rep(NaN,531))
+#' make_barplot_on_models_stats(models.stats = table(x, useNA = "ifany"),
+#' title = "True Positives Distribution across models",
+#' xlab = "Number of TP values", ylab = "Number of models")
 #'
 #' @importFrom graphics barplot axis par
 #' @export
 make_barplot_on_models_stats =
-  function(models.stats, cell.line, title, xlab, ylab, cont.values = FALSE, threshold = 0) {
+  function(models.stats, cell.line = NULL, title, xlab, ylab, cont.values = FALSE, threshold = 0, ylim.add = 0) {
     if (!is.null(cell.line))
       cell.line.text = paste0(" (", cell.line, ")")
     else
@@ -94,7 +109,7 @@ make_barplot_on_models_stats =
 
     bp = barplot(models.stats, col = "cornflowerblue",
                  names.arg = x.axis.values, yaxt = "n",
-                 ylim = c(0, max(y.axis.values) + 500),
+                 ylim = c(0, max(y.axis.values) + ylim.add),
                  main = paste0(title, cell.line.text),
                  xlab = xlab, ylab = ylab)
     axis(2, at = y.axis.values, las = 1)
@@ -106,6 +121,8 @@ make_barplot_on_models_stats =
       text(x = bp[1], y = nan.value/2, labels = names(nan.value),
            col = "yellow", srt = 90, font = 2)
     }
+
+    TRUE
 }
 
 #' Get the refined x-axis values
@@ -155,36 +172,46 @@ get_x_axis_values =
 #' size = 2 => bottom.margin = 6,
 #' size = 3 => bottom.margin = 9,
 #' size = 4 => bottom.margin = 12, etc.
+#' @param ylim.add integer. Signifies the height to add to the upper
+#' \code{ylim} parameter on the barplot, in addition to the maximum bar height
+#' across the whole plot. Default value is 0.
 #' @param cell.line string. The name of the cell line to be used in the title
 #' of the produced plot. Default value: NULL (the cell line name will not be
 #' added to the title).
 #'
+#' @examples
+#' synergy.subset.stats = c(1,4,3,2)
+#' names(synergy.subset.stats) = c("A-B", "B-C", "C-A", "C-D")
+#' make_barplot_on_synergy_subset_stats(synergy.subset.stats,
+#' threshold.for.subset.removal = 0, bottom.margin = 4, ylim.add = 0.5)
+#'
 #' @export
-make_barplot_on_synergy_subset_stats =
-  function(synergy.subset.stats, threshold.for.subset.removal, bottom.margin,
-           cell.line = NULL) {
-    if (!is.null(cell.line))
-      cell.line.text = paste0(" (", cell.line, ")")
-    else
-      cell.line.text = ""
+make_barplot_on_synergy_subset_stats = function(synergy.subset.stats,
+  threshold.for.subset.removal, bottom.margin, ylim.add = 0, cell.line = NULL) {
+  if (!is.null(cell.line))
+    cell.line.text = paste0(" (", cell.line, ")")
+  else
+    cell.line.text = ""
 
-    synergy.subset.stats = synergy.subset.stats[
-      !synergy.subset.stats < threshold.for.subset.removal
-    ]
+  synergy.subset.stats = synergy.subset.stats[
+    !synergy.subset.stats < threshold.for.subset.removal
+  ]
 
-    oldpar = par('mar')
-    par(mar = c(bottom.margin, 4, 4, 2)) # c(bottom, left, top, right)
-    on.exit(par(oldpar))
+  oldpar = par('mar')
+  par(mar = c(bottom.margin, 4, 4, 2)) # c(bottom, left, top, right)
+  on.exit(par(oldpar))
 
-    y.axis.values = pretty(synergy.subset.stats)
-    bp = barplot(synergy.subset.stats, col = "green", space = 0.5, las = 2,
-                 main = paste0("Model Synergy Predictions per Observed Synergy",
-                                " Subset", cell.line.text),
-                 ylab = "Number of models", yaxt = "n",
-                 ylim = c(0, max(y.axis.values) + 500))
-    axis(2, at = y.axis.values, las = 1)
+  y.axis.values = pretty(synergy.subset.stats)
+  bp = barplot(synergy.subset.stats, col = "green", space = 0.5, las = 2,
+               main = paste0("Model Synergy Predictions per Observed Synergy",
+                              " Subset", cell.line.text),
+               ylab = "Number of models", yaxt = "n",
+               ylim = c(0, max(y.axis.values) + ylim.add))
+  axis(2, at = y.axis.values, las = 1)
 
-    add_numbers_above_the_bars(synergy.subset.stats, bp, color = "red")
+  add_numbers_above_the_bars(synergy.subset.stats, bp, color = "red")
+
+  TRUE
 }
 
 #' Add numbers horizontally above the bars of a barplot
@@ -205,29 +232,34 @@ add_numbers_above_the_bars = function(stats, bp, color) {
 #' Plot the graph of average state differences (visNetwork)
 #'
 #' This function uses the \code{\link[visNetwork]{visNetwork}} package to plot a
-#' network of nodes. The nodes are positioned according to the specified coordinates
-#' given by the \code{layout} parameter and the colors are derived using the
-#' \code{diff} values and the \code{\link{get_node_colors}} function. The color
-#' of each node indicates how much more inhibited or active that node is, when
-#' comparing the average model classified in the 'good' category vs the average
-#' 'bad' one.
+#' network of nodes. The nodes are positioned by default in a hierarchical layout
+#' and their colors are derived using the \code{diff} values and the
+#' \code{\link{get_node_colors}} function. The color of each node indicates how
+#' much more inhibited or active that node is, when comparing the average model
+#' classified in the 'good' category vs the average 'bad' one.
 #'
-#' @param net igraph graph object (to be translated to a \emph{visNetwork} object)
-#' @param diff numeric vector. Every value is in the [-1,1] interval and
+#' @param net igraph graph object (to be translated to a \code{visNetwork} object)
+#' @param diff numeric vector. Every value must be in the [-1,1] interval and
 #' represents the average activity difference of each node. The node names have
 #' to be specified in the \emph{names} attribute of the given vector. For example,
 #' \code{diff} could be the result of using the function
-#' \code{\link{get_avg_activity_diff_based_on_specific_synergy_prediction}}.
-#' @param layout a (nx2) numeric matrix of x-y coordinates (2 columns) for each
-#' of the nodes (n) in the \code{net} igraph object
-#' @param title string. The title of the visNetwork plot
+#' \code{\link{get_avg_activity_diff_based_on_specific_synergy_prediction}}
+#' @param nodes.size an integer specifying the size of the nodes. Default value: 20.
+#' @param title string. The title of the \code{visNetwork} plot.
+#'
+#' @examples
+#' topology.file = system.file("extdata", "example.sif", package = "emba", mustWork = TRUE)
+#' net = construct_network(topology.file)
+#' diff = c(-0.95,-0.05,0.46,0.39,-0.04,0.72,-0.12,-0.51,-0.86,-0.80)
+#' names(diff) = c("A","C","B","D","W","I","E","J","F","K")
+#' plot_avg_state_diff_graph_vis(net, diff, title = "TEST")
 #'
 #' @family network plotting functions
 #'
-#' @importFrom magrittr %>%
+#' @importFrom tidyr %>%
 #' @importFrom visNetwork toVisNetworkData visNetwork visLegend
 #' @export
-plot_avg_state_diff_graph_vis = function(net, diff, layout, title) {
+plot_avg_state_diff_graph_vis = function(net, diff, nodes.size = 20, title) {
   data = toVisNetworkData(net)
   nodes = data$nodes
   edges = data$edges
@@ -237,12 +269,9 @@ plot_avg_state_diff_graph_vis = function(net, diff, layout, title) {
   nodes$color = get_node_colors(net, diff, col)
 
   # set visualization graph attributes
-  nodes$size = 30
+  nodes$size = nodes.size
   nodes$physics = FALSE
   nodes$shape = "dot"
-  scale.factor = 60
-  nodes$x = layout[,2] * scale.factor
-  nodes$y = layout[,1] * scale.factor
 
   edges$smooth = FALSE
   edges$physics = FALSE
@@ -250,8 +279,7 @@ plot_avg_state_diff_graph_vis = function(net, diff, layout, title) {
 
   # set legend properties
   legend.nodes = data.frame(
-    label = c("More inhibited","No difference", "More activated"), color = col
-  )
+    label = c("More inhibited","No difference", "More activated"), color = col)
 
   # plot the network
   visNetwork(nodes, edges, main = title, width = "100%") %>%
@@ -261,7 +289,7 @@ plot_avg_state_diff_graph_vis = function(net, diff, layout, title) {
 
 #' Plot the graph of average state differences (igraph)
 #'
-#' This function uses the \code{\link[igraph]{igraph}} package to plot a network
+#' This function uses the \code{\link[igraph]{plot.igraph}} package to plot a network
 #' of nodes. The nodes are positioned according to the specified coordinates
 #' given by the \code{layout} parameter and the colors are derived using the
 #' \code{diff} values and the \code{\link{get_node_colors}} function. The color
@@ -276,18 +304,26 @@ plot_avg_state_diff_graph_vis = function(net, diff, layout, title) {
 #' \code{diff} could be the result of using the function
 #' \code{\link{get_avg_activity_diff_based_on_tp_predictions}}.
 #' @param layout a (nx2) numeric matrix of x-y coordinates (2 columns) for each
-#' of the nodes (n) in the \code{net} igraph object
+#' of the nodes (n) in the \code{net} igraph object. If NULL, we use the default
+#' layout provided by \code{\link[igraph]{layout_nicely}}.
 #' @param title string. The title of the igraph plot
 #'
+#' @examples
+#' topology.file = system.file("extdata", "example.sif", package = "emba", mustWork = TRUE)
+#' net = construct_network(topology.file)
+#' diff = c(-0.95,-0.05,0.46,0.39,-0.04,0.72,-0.12,-0.51,-0.86,-0.80)
+#' names(diff) = c("A","C","B","D","W","I","E","J","F","K")
+#' plot_avg_state_diff_graph(net, diff, title = "TEST")
+#'
 #' @family network plotting functions
 #'
 #' @seealso
 #' \code{\link{get_node_colors}}
 #'
-#' @importFrom igraph plot.igraph V
+#' @importFrom igraph plot.igraph V layout_nicely
 #' @importFrom graphics legend
 #' @export
-plot_avg_state_diff_graph = function(net, diff, layout, title) {
+plot_avg_state_diff_graph = function(net, diff, layout = NULL, title) {
   # colors for nodes (to be interpolated) matching one-to-one the diff values
   col = c("tomato", "grey", "gold")
   V(net)$color = get_node_colors(net, diff, col)
@@ -297,16 +333,22 @@ plot_avg_state_diff_graph = function(net, diff, layout, title) {
   par(mar = c(0, 0, 1, 0)) # c(bottom, left, top, right)
   on.exit(par(oldpar))
 
+  if (is.null(layout)) {
+    layout = layout_nicely(net)
+  }
+
   plot.igraph(net, asp = 0, layout = layout, main = title)
   legend(x = -1.1, y = -0.7, pch = 21, col = "#777777",
         legend = c("More inhibited", "No difference", "More activated"),
         title = expression(bold("Good model activity state")),
         pt.bg = col, pt.cex = 2, cex = 0.8, bty = "n", ncol = 1)
+
+  TRUE
 }
 
 #' Plot the graph of average link operator differences (igraph)
 #'
-#' This function uses the \code{\link[igraph]{igraph}} package to plot a network
+#' This function uses the \code{\link[igraph]{plot.igraph}} package to plot a network
 #' of nodes. The nodes are positioned according to the specified coordinates
 #' given by the \code{layout} parameter and the colors are derived using the
 #' \code{diff} values and the \code{\link{get_node_colors}} function. The color
@@ -326,20 +368,27 @@ plot_avg_state_diff_graph = function(net, diff, layout, title) {
 #' A value closer to -1 means that the 'good' models have more of the \emph{AND NOT}
 #' link operator in their respective boolean equations while a value closer to 1
 #' means that the 'good' models have more of the \emph{OR NOT} link operator.
-
 #' @param layout a (nx2) numeric matrix of x-y coordinates (2 columns) for each
-#' of the nodes (n) in the \code{net} igraph object
+#' of the nodes (n) in the \code{net} igraph object. If NULL, we use the default
+#' layout provided by \code{\link[igraph]{layout_nicely}}.
 #' @param title string. The title of the igraph plot
 #'
+#' @examples
+#' topology.file = system.file("extdata", "example.sif", package = "emba", mustWork = TRUE)
+#' net = construct_network(topology.file)
+#' diff = c(-0.95,-0.05,0.46,0.39,-0.04,0.72,-0.12,-0.51)
+#' names(diff) = c("A","C","B","D","W","I","E","J")
+#' plot_avg_link_operator_diff_graph(net, diff, title = "TEST")
+#'
 #' @family network plotting functions
 #'
 #' @seealso
 #' \code{\link{get_node_colors}}
 #'
-#' @importFrom igraph plot.igraph V
+#' @importFrom igraph plot.igraph V layout_nicely
 #' @importFrom graphics legend
 #' @export
-plot_avg_link_operator_diff_graph = function(net, diff, layout, title) {
+plot_avg_link_operator_diff_graph = function(net, diff, layout = NULL, title) {
   # colors for nodes (to be interpolated) matching one-to-one the diff values
   col = c("tomato", "grey", "gold")
   col.2 = c("tomato", "gold", "grey", "white")
@@ -350,11 +399,17 @@ plot_avg_link_operator_diff_graph = function(net, diff, layout, title) {
   par(mar = c(0, 0, 1, 0)) # c(bottom, left, top, right)
   on.exit(par(oldpar))
 
+  if (is.null(layout)) {
+    layout = layout_nicely(net)
+  }
+
   plot.igraph(net, asp = 0, layout = layout, main = title)
   legend(x = -1.1, y = -0.6, pch = 21, col = "#777777",
          legend = c("AND NOT", "OR NOT", "No difference", "no link operator"),
          title = expression(bold("Good model link operator")),
          pt.bg = col.2, pt.cex = 2, cex = 0.8, bty = "n", ncol = 1)
+
+  TRUE
 }
 
 #' Get the node colors
@@ -417,8 +472,8 @@ get_node_colors = function(net, diff, col) {
 
 #' Plot the graphs from an average state differences matrix
 #'
-#' This function presents a convenient way to use many times the
-#' \code{\link{plot_avg_state_diff_graph}} function.
+#' This function presents a convenient way to use the function
+#' \code{\link{plot_avg_state_diff_graph}} multiple times.
 #'
 #' @param net igraph graph object
 #' @param diff.mat a matrix whose rows are \strong{vectors of average node activity
@@ -427,24 +482,28 @@ get_node_colors = function(net, diff, col) {
 #' attribute of the matrix (usually denoting the different classification
 #' groups, e.g. (1,2) means the models that predicted 1 TP synergy vs the models
 #' that predicted 2 TP synergies, if the classification is done by number of TP
-#' predictions). The columns represent the network's node names.
+#' predictions). The columns represent the network's node names. Could be the
+#' result of using the function \code{\link{get_avg_activity_diff_mat_based_on_tp_predictions}}.
 #' @param layout a (nx2) numeric matrix of x-y coordinates (2 columns) for each
-#' of the nodes (n) in the \code{net} igraph object
+#' of the nodes (n) in the \code{net} igraph object. If NULL, we use the default
+#' layout provided by \code{\link[igraph]{layout_nicely}}.
 #'
 #' @family network plotting functions
 #'
 #' @export
-plot_avg_state_diff_graphs = function(net, diff.mat, layout) {
+plot_avg_state_diff_graphs = function(net, diff.mat, layout = NULL) {
   for (row.index in 1:nrow(diff.mat)) {
     plot_avg_state_diff_graph(net, diff.mat[row.index, ], layout = layout,
                               title = rownames(diff.mat)[row.index])
   }
+
+  TRUE
 }
 
 #' Plot the graphs from an average link operator differences matrix
 #'
-#' This function presents a convenient way to use many times the
-#' \code{\link{plot_avg_link_operator_diff_graph}} function.
+#' This function presents a convenient way to use the
+#' \code{\link{plot_avg_link_operator_diff_graph}} function multiple times.
 #'
 #' @param net igraph graph object
 #' @param diff.mat a matrix whose rows are \strong{vectors of average node link
@@ -453,17 +512,20 @@ plot_avg_state_diff_graphs = function(net, diff.mat, layout) {
 #' attribute of the matrix (usually denoting the different classification
 #' groups, e.g. (1,2) means the models that predicted 1 TP synergy vs the models
 #' that predicted 2 TP synergies, if the classification is done by number of TP
-#' predictions). The columns represent the network's node names.
+#' predictions). The columns represent the network's node names. Could be the
+#' result of using the function \code{\link{get_avg_link_operator_diff_mat_based_on_tp_predictions}}.
 #' @param layout a (nx2) numeric matrix of x-y coordinates (2 columns) for each
-#' of the nodes (n) in the \code{net} igraph object
+#' of the nodes (n) in the \code{net} igraph object. If NULL, we use the default
+#' layout provided by \code{\link[igraph]{layout_nicely}}.
 #'
 #' @family network plotting functions
 #'
 #' @export
-plot_avg_link_operator_diff_graphs = function(net, diff.mat, layout) {
+plot_avg_link_operator_diff_graphs = function(net, diff.mat, layout = NULL) {
   for (row.index in 1:nrow(diff.mat)) {
     plot_avg_link_operator_diff_graph(net, diff.mat[row.index, ], layout = layout,
                                       title = rownames(diff.mat)[row.index])
   }
-}
 
+  TRUE
+}
